==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VMGalleryApplicationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the required information to reference a compute gallery application version
 * @property configurationReference Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
 * @property enableAutomaticUpgrade If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
 * @property order Optional, Specifies the order in which the packages have to be installed
 * @property packageReferenceId Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
 * @property tags Optional, Specifies a passthrough value for more generic context.
 * @property treatFailureAsDeploymentFailure Optional, If true, any failure for any operation in the VmApplication will fail the deployment
 */
public data class VMGalleryApplicationArgs(
    public val configurationReference: Output<String>? = null,
    public val enableAutomaticUpgrade: Output<Boolean>? = null,
    public val order: Output<Int>? = null,
    public val packageReferenceId: Output<String>,
    public val tags: Output<String>? = null,
    public val treatFailureAsDeploymentFailure: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs =
        com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs.builder()
            .configurationReference(configurationReference?.applyValue({ args0 -> args0 }))
            .enableAutomaticUpgrade(enableAutomaticUpgrade?.applyValue({ args0 -> args0 }))
            .order(order?.applyValue({ args0 -> args0 }))
            .packageReferenceId(packageReferenceId.applyValue({ args0 -> args0 }))
            .tags(tags?.applyValue({ args0 -> args0 }))
            .treatFailureAsDeploymentFailure(
                treatFailureAsDeploymentFailure?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [VMGalleryApplicationArgs].
 */
@PulumiTagMarker
public class VMGalleryApplicationArgsBuilder internal constructor() {
    private var configurationReference: Output<String>? = null

    private var enableAutomaticUpgrade: Output<Boolean>? = null

    private var order: Output<Int>? = null

    private var packageReferenceId: Output<String>? = null

    private var tags: Output<String>? = null

    private var treatFailureAsDeploymentFailure: Output<Boolean>? = null

    /**
     * @param value Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
     */
    @JvmName("ykrrvgucahtehdkl")
    public suspend fun configurationReference(`value`: Output<String>) {
        this.configurationReference = value
    }

    /**
     * @param value If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
     */
    @JvmName("wsaphnsjvldixikk")
    public suspend fun enableAutomaticUpgrade(`value`: Output<Boolean>) {
        this.enableAutomaticUpgrade = value
    }

    /**
     * @param value Optional, Specifies the order in which the packages have to be installed
     */
    @JvmName("hhvdkfrelsweyxji")
    public suspend fun order(`value`: Output<Int>) {
        this.order = value
    }

    /**
     * @param value Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
     */
    @JvmName("tcwvdqbpagydecbj")
    public suspend fun packageReferenceId(`value`: Output<String>) {
        this.packageReferenceId = value
    }

    /**
     * @param value Optional, Specifies a passthrough value for more generic context.
     */
    @JvmName("iehluwuuhshposnj")
    public suspend fun tags(`value`: Output<String>) {
        this.tags = value
    }

    /**
     * @param value Optional, If true, any failure for any operation in the VmApplication will fail the deployment
     */
    @JvmName("empnlwpsbhrvtoel")
    public suspend fun treatFailureAsDeploymentFailure(`value`: Output<Boolean>) {
        this.treatFailureAsDeploymentFailure = value
    }

    /**
     * @param value Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
     */
    @JvmName("jrixekbjrwaftqdm")
    public suspend fun configurationReference(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationReference = mapped
    }

    /**
     * @param value If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
     */
    @JvmName("xtutrgcmbsqysihc")
    public suspend fun enableAutomaticUpgrade(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAutomaticUpgrade = mapped
    }

    /**
     * @param value Optional, Specifies the order in which the packages have to be installed
     */
    @JvmName("trppwplixponfvhs")
    public suspend fun order(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
     */
    @JvmName("iaoashabmnduhrwj")
    public suspend fun packageReferenceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.packageReferenceId = mapped
    }

    /**
     * @param value Optional, Specifies a passthrough value for more generic context.
     */
    @JvmName("xuaaalxmlbyywukr")
    public suspend fun tags(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Optional, If true, any failure for any operation in the VmApplication will fail the deployment
     */
    @JvmName("eusdiefqepaxivfj")
    public suspend fun treatFailureAsDeploymentFailure(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.treatFailureAsDeploymentFailure = mapped
    }

    internal fun build(): VMGalleryApplicationArgs = VMGalleryApplicationArgs(
        configurationReference = configurationReference,
        enableAutomaticUpgrade = enableAutomaticUpgrade,
        order = order,
        packageReferenceId = packageReferenceId ?: throw PulumiNullFieldException("packageReferenceId"),
        tags = tags,
        treatFailureAsDeploymentFailure = treatFailureAsDeploymentFailure,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VMGalleryApplicationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the required information to reference a compute gallery application version
 * @property configurationReference Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
 * @property enableAutomaticUpgrade If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
 * @property order Optional, Specifies the order in which the packages have to be installed
 * @property packageReferenceId Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
 * @property tags Optional, Specifies a passthrough value for more generic context.
 * @property treatFailureAsDeploymentFailure Optional, If true, any failure for any operation in the VmApplication will fail the deployment
 */
public data class VMGalleryApplicationArgs(
    public val configurationReference: Output<String>? = null,
    public val enableAutomaticUpgrade: Output<Boolean>? = null,
    public val order: Output<Int>? = null,
    public val packageReferenceId: Output<String>,
    public val tags: Output<String>? = null,
    public val treatFailureAsDeploymentFailure: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs =
        com.pulumi.azurenative.compute.inputs.VMGalleryApplicationArgs.builder()
            .configurationReference(configurationReference?.applyValue({ args0 -> args0 }))
            .enableAutomaticUpgrade(enableAutomaticUpgrade?.applyValue({ args0 -> args0 }))
            .order(order?.applyValue({ args0 -> args0 }))
            .packageReferenceId(packageReferenceId.applyValue({ args0 -> args0 }))
            .tags(tags?.applyValue({ args0 -> args0 }))
            .treatFailureAsDeploymentFailure(
                treatFailureAsDeploymentFailure?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [VMGalleryApplicationArgs].
 */
@PulumiTagMarker
public class VMGalleryApplicationArgsBuilder internal constructor() {
    private var configurationReference: Output<String>? = null

    private var enableAutomaticUpgrade: Output<Boolean>? = null

    private var order: Output<Int>? = null

    private var packageReferenceId: Output<String>? = null

    private var tags: Output<String>? = null

    private var treatFailureAsDeploymentFailure: Output<Boolean>? = null

    /**
     * @param value Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
     */
    @JvmName("pfbbxmrcusxnbcjq")
    public suspend fun configurationReference(`value`: Output<String>) {
        this.configurationReference = value
    }

    /**
     * @param value If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
     */
    @JvmName("uhchfwqtjmaqyvri")
    public suspend fun enableAutomaticUpgrade(`value`: Output<Boolean>) {
        this.enableAutomaticUpgrade = value
    }

    /**
     * @param value Optional, Specifies the order in which the packages have to be installed
     */
    @JvmName("ucpmwevgpktumuap")
    public suspend fun order(`value`: Output<Int>) {
        this.order = value
    }

    /**
     * @param value Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
     */
    @JvmName("bipmysgxyvisorhj")
    public suspend fun packageReferenceId(`value`: Output<String>) {
        this.packageReferenceId = value
    }

    /**
     * @param value Optional, Specifies a passthrough value for more generic context.
     */
    @JvmName("rwatsolotflmupjs")
    public suspend fun tags(`value`: Output<String>) {
        this.tags = value
    }

    /**
     * @param value Optional, If true, any failure for any operation in the VmApplication will fail the deployment
     */
    @JvmName("ufydxvcegupyoxxw")
    public suspend fun treatFailureAsDeploymentFailure(`value`: Output<Boolean>) {
        this.treatFailureAsDeploymentFailure = value
    }

    /**
     * @param value Optional, Specifies the uri to an azure blob that will replace the default configuration for the package if provided
     */
    @JvmName("jrtlajayltxwproq")
    public suspend fun configurationReference(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationReference = mapped
    }

    /**
     * @param value If set to true, when a new Gallery Application version is available in PIR/SIG, it will be automatically updated for the VM/VMSS
     */
    @JvmName("toiceuybyiymrqkb")
    public suspend fun enableAutomaticUpgrade(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAutomaticUpgrade = mapped
    }

    /**
     * @param value Optional, Specifies the order in which the packages have to be installed
     */
    @JvmName("llacdyitrwklfdqx")
    public suspend fun order(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value Specifies the GalleryApplicationVersion resource id on the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/providers/Microsoft.Compute/galleries/{galleryName}/applications/{application}/versions/{version}
     */
    @JvmName("imlwlrtqugfqjtbf")
    public suspend fun packageReferenceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.packageReferenceId = mapped
    }

    /**
     * @param value Optional, Specifies a passthrough value for more generic context.
     */
    @JvmName("ekrwvvbjswkulplf")
    public suspend fun tags(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Optional, If true, any failure for any operation in the VmApplication will fail the deployment
     */
    @JvmName("ogmcvhqekjesofqa")
    public suspend fun treatFailureAsDeploymentFailure(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.treatFailureAsDeploymentFailure = mapped
    }

    internal fun build(): VMGalleryApplicationArgs = VMGalleryApplicationArgs(
        configurationReference = configurationReference,
        enableAutomaticUpgrade = enableAutomaticUpgrade,
        order = order,
        packageReferenceId = packageReferenceId ?: throw PulumiNullFieldException("packageReferenceId"),
        tags = tags,
        treatFailureAsDeploymentFailure = treatFailureAsDeploymentFailure,
    )
}
